JBoss Portal SVN: r10925 - in modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2: spi and 1 other directory.
by portal-commits@lists.jboss.org
Author: bdaw
Date: 2008-06-04 16:10:25 -0400 (Wed, 04 Jun 2008)
New Revision: 10925
Modified:
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java
Log:
minor
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java 2008-06-04 19:10:31 UTC (rev 10924)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java 2008-06-04 20:10:25 UTC (rev 10925)
@@ -25,7 +25,6 @@
import java.util.Map;
import java.util.Set;
-import java.util.Collection;
/**
*
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java 2008-06-04 19:10:31 UTC (rev 10924)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java 2008-06-04 20:10:25 UTC (rev 10925)
@@ -24,9 +24,7 @@
import org.jboss.portal.identity2.api.GroupType;
-import java.util.List;
import java.util.Map;
-import java.util.Set;
import java.util.Collection;
/**
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java 2008-06-04 19:10:31 UTC (rev 10924)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java 2008-06-04 20:10:25 UTC (rev 10925)
@@ -22,7 +22,10 @@
package org.jboss.portal.identity2.spi;
+import org.jboss.portal.identity2.api.GroupType;
+
import java.util.Set;
+import java.util.Map;
/**
* IdentityRepository exposes identity object management operations and act as an entry point to the underlaying data stores.
@@ -33,5 +36,20 @@
*/
public interface IdentityRepository
{
+ /**
+ * @return a set of configured identity stores
+ */
Set<IdentityStore> getConfiguredIdentityStores();
+
+ /**
+ * @return mapping of GroupType to the specific idenity store
+ */
+ Map<GroupType, IdentityStore> getIdentityStoreMappings();
+
+ /**
+ * @param groupType
+ * @return proper identity store to store given group type
+ */
+ IdentityStore getIdentityStore(GroupType groupType);
+
}
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java 2008-06-04 19:10:31 UTC (rev 10924)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java 2008-06-04 20:10:25 UTC (rev 10925)
@@ -40,8 +40,11 @@
boolean isUserStore();
+ boolean supportExternalGroupRelationships();
+
// TODO: Set of needed methods
+ // TODO: Mechanism for extensions and dynamic discovery of supported extended operations
}
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java 2008-06-04 19:10:31 UTC (rev 10924)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java 2008-06-04 20:10:25 UTC (rev 10925)
@@ -22,7 +22,6 @@
package org.jboss.portal.identity2.spi;
-import java.util.List;
import java.util.Map;
import java.util.Collection;
17 years, 11 months
JBoss Portal SVN: r10924 - in modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2: spi and 1 other directory.
by portal-commits@lists.jboss.org
Author: bdaw
Date: 2008-06-04 15:10:31 -0400 (Wed, 04 Jun 2008)
New Revision: 10924
Removed:
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationType.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityService.java
Modified:
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java
Log:
some refactorings
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java 2008-06-04 18:59:16 UTC (rev 10923)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java 2008-06-04 19:10:31 UTC (rev 10924)
@@ -38,22 +38,22 @@
/**
* @return group id
*/
- public Object getId();
+ Object getId();
/**
* @return group name
*/
- public String getName();
+ String getName();
/**
* @return group type
*/
- public GroupType getType();
+ GroupType getType();
/**
* @return map containing group attributes
*/
- public Map<String, String[]> getAttributes();
+ Map<String, String[]> getAttributes();
/**
* Update user attribute values
@@ -61,36 +61,36 @@
* @param values
* @return
*/
- public boolean updateAttribute(String attrName, String[] values);
+ boolean updateAttribute(String attrName, String[] values);
/**
* @return id of parent group for the relations of RelationType.HIERARCHICAL. If the parent id is null, this object
* is a child of a root group in the store
*/
- public Object getParentId();
+ Object getParentId();
/**
* @return set of users assigned to this group
*/
- public Set<User> getUsers();
+ Set<User> getUsers();
/**
* @return set of groups that are either children of this group or implied for this group
*/
- public Set<Group> getGroups();
+ Set<Group> getGroups();
/**
* @param type of the relation
* @return set of groups that have given relation type with this group and the direction of the relation is towords
* this group
*/
- public Set<Group> getGroups(RelationshipType type);
+ Set<Group> getGroups(RelationshipType type);
/**
* @param group
* @return returns a relationship type between this and given group.
*/
- public RelationshipType getRelationship(Group group);
+ RelationshipType getRelationship(Group group);
/**
* Assign a set of groups to this group. All other group associations (with this relation type) for this group
@@ -99,13 +99,13 @@
* @param type
* @return
*/
- public boolean assignGroups(Set<Group> toGroups, RelationshipType type);
+ boolean assignGroups(Set<Group> toGroups, RelationshipType type);
/**
* Assign a set of users to this group. All other user associations will be overwritten for this group
* @param users
* @return
*/
- public boolean assignUsers(Set<User> users);
+ boolean assignUsers(Set<User> users);
}
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java 2008-06-04 18:59:16 UTC (rev 10923)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java 2008-06-04 19:10:31 UTC (rev 10924)
@@ -42,35 +42,35 @@
* @param userName
* @return
*/
- public User createUser(String userName);
+ User createUser(String userName);
/**
* Remove user from the the data store
* @param user
* @return
*/
- public boolean removeUser(User user);
+ boolean removeUser(User user);
/**
* Find user with a given user name
* @param userName
* @return
*/
- public User findUser(String userName);
+ User findUser(String userName);
/**
* Find user with a given id
* @param id
* @return
*/
- public User findUser(Object id);
+ User findUser(Object id);
/**
* Find users with a given properties values
* @param properties
* @return
*/
- public Set<Group> findUsers(Map<String, String[]> properties);
+ Set<Group> findUsers(Map<String, String[]> properties);
// Groups
@@ -80,45 +80,40 @@
* @param groupName
* @return
*/
- public Group createGroup(String groupName, GroupType type);
+ Group createGroup(String groupName, GroupType type);
/**
* Remove group from the data store
* @param group
* @return
*/
- public boolean removeGroup(Group group);
+ boolean removeGroup(Group group);
/**
* Find group with a given name
* @param name
* @return
*/
- public Group findGroup(String name);
+ Group findGroup(String name);
/**
* Find Group with a given object id
* @param id
* @return
*/
- public Group findGroup(Object id);
+ Group findGroup(Object id);
/**
* Find Group with a given group type
* @param groupType
* @return
*/
- public Group findGroup(GroupType groupType);
+ Group findGroup(GroupType groupType);
/**
* Find groups with a given attributes values
* @param properties
* @return
*/
- public Set<Group> findGroups(Map<String, String[]> properties);
-
-
-
-
-
+ Set<Group> findGroups(Map<String, String[]> properties);
}
Deleted: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationType.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationType.java 2008-06-04 18:59:16 UTC (rev 10923)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationType.java 2008-06-04 19:10:31 UTC (rev 10924)
@@ -1,35 +0,0 @@
-/*
-* JBoss, a division of Red Hat
-* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
-* by the @authors tag. See the copyright.txt in the distribution for a
-* full listing of individual contributors.
-*
-* This is free software; you can redistribute it and/or modify it
-* under the terms of the GNU Lesser General Public License as
-* published by the Free Software Foundation; either version 2.1 of
-* the License, or (at your option) any later version.
-*
-* This software is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this software; if not, write to the Free
-* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-*/
-
-package org.jboss.portal.identity2.api;
-
-/**
- * Relation between two groups
- */
-public enum RelationType
-{
- // Tree like hierarchy (parent -> children)
- HIERARCHICAL,
-
- // Implied
- IMPLIED
-}
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java 2008-06-04 18:59:16 UTC (rev 10923)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java 2008-06-04 19:10:31 UTC (rev 10924)
@@ -36,17 +36,17 @@
/**
* @return user id
*/
- public Object getId();
+ Object getId();
/**
* @return user name
*/
- public String getUserName();
+ String getUserName();
/**
* @return map containing user attributes
*/
- public Map<String, String[]> getAttributes();
+ Map<String, String[]> getAttributes();
/**
* Update user attribute values
@@ -54,24 +54,24 @@
* @param values
* @return
*/
- public boolean updateAttribute(String attrName, String[] values);
+ boolean updateAttribute(String attrName, String[] values);
/**
* @return a set of groups that this user belongs to
*/
- public Set<Group> getGroups();
+ Set<Group> getGroups();
/**
* @param groupType
* @return a set of groups with a given groupType that this user belongs to
*/
- public Set<Group> getGroups(GroupType groupType);
+ Set<Group> getGroups(GroupType groupType);
/**
* Assign a set of groups to this user. All other group associations will be overwritten
* @param groups
* @return
*/
- public boolean assignGroups(Set<Group> groups);
+ boolean assignGroups(Set<Group> groups);
}
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java 2008-06-04 18:59:16 UTC (rev 10923)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java 2008-06-04 19:10:31 UTC (rev 10924)
@@ -25,7 +25,7 @@
import java.util.Set;
/**
- * IdentityRepositoryexposes identity object management operations and act as an entry point to the underlaying data stores.
+ * IdentityRepository exposes identity object management operations and act as an entry point to the underlaying data stores.
* Its responsibility is to map identity objects, their state and relations between them across different identity stores.
*
* @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
Deleted: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityService.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityService.java 2008-06-04 18:59:16 UTC (rev 10923)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityService.java 2008-06-04 19:10:31 UTC (rev 10924)
@@ -1,37 +0,0 @@
-/*
-* JBoss, a division of Red Hat
-* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
-* by the @authors tag. See the copyright.txt in the distribution for a
-* full listing of individual contributors.
-*
-* This is free software; you can redistribute it and/or modify it
-* under the terms of the GNU Lesser General Public License as
-* published by the Free Software Foundation; either version 2.1 of
-* the License, or (at your option) any later version.
-*
-* This software is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this software; if not, write to the Free
-* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-*/
-
-package org.jboss.portal.identity2.spi;
-
-import java.util.Set;
-
-/**
- * IdentityService exposes identity object management operations and act as an entry point to the underlaying data stores.
- * Its responsibility is to map identity objects, their state and relations between them across different identity stores.
- *
- * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
- * @version : 0.1 $
- */
-public interface IdentityService
-{
- public Set<IdentityStore> getConfiguredIdentityStores();
-}
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java 2008-06-04 18:59:16 UTC (rev 10923)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java 2008-06-04 19:10:31 UTC (rev 10924)
@@ -24,8 +24,7 @@
import org.jboss.portal.identity2.api.GroupType;
-import java.util.Map;
-import java.util.List;
+
import java.util.Set;
/**
17 years, 11 months
JBoss Portal SVN: r10923 - in modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2: spi and 1 other directory.
by portal-commits@lists.jboss.org
Author: bdaw
Date: 2008-06-04 14:59:16 -0400 (Wed, 04 Jun 2008)
New Revision: 10923
Added:
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationshipType.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relationship.java
Removed:
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relation.java
Modified:
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java
Log:
some refactorings
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java 2008-06-04 18:41:14 UTC (rev 10922)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -25,6 +25,7 @@
import java.util.Map;
import java.util.Set;
+import java.util.Collection;
/**
* IdentityModule exposes operations to creat/destroy/find users and roles. Methods to manipulate those objects and
Copied: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationshipType.java (from rev 10922, modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationType.java)
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationshipType.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationshipType.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -0,0 +1,35 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.api;
+
+/**
+ * Relationship between two groups
+ */
+public enum RelationshipType
+{
+ // Tree like hierarchy (parent -> children)
+ HIERARCHICAL,
+
+ // Implied
+ IMPLIED
+}
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java 2008-06-04 18:41:14 UTC (rev 10922)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -24,6 +24,7 @@
import java.util.Map;
import java.util.Set;
+import java.util.Collection;
/**
* @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
@@ -49,12 +50,11 @@
/**
* Update user attribute values
- * @param user
* @param attrName
* @param values
* @return
*/
- public boolean updateAttribute(User user, String attrName, String[] values);
+ public boolean updateAttribute(String attrName, String[] values);
/**
* @return a set of groups that this user belongs to
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java 2008-06-04 18:41:14 UTC (rev 10922)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -26,6 +26,8 @@
import java.util.List;
import java.util.Map;
+import java.util.Set;
+import java.util.Collection;
/**
* @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
@@ -33,20 +35,20 @@
*/
public interface GroupEntity
{
- public Object getId();
+ Object getId();
- public String getName();
+ String getName();
- public GroupType getType();
+ GroupType getType();
- public Map<String, String[]> getAttributes();
+ Map<String, String[]> getAttributes();
- public Object getParentId();
+ Object getParentId();
- public List<Relation> getFromRelations();
+ Collection<Relationship> getFromRelations();
- public List<Relation> getToRelations();
+ Collection<Relationship> getToRelations();
- public List<UserEntity> getUserEntities();
+ Collection<UserEntity> getUserEntities();
}
Copied: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java (from rev 10922, modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityService.java)
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityRepository.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -0,0 +1,37 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.spi;
+
+import java.util.Set;
+
+/**
+ * IdentityRepositoryexposes identity object management operations and act as an entry point to the underlaying data stores.
+ * Its responsibility is to map identity objects, their state and relations between them across different identity stores.
+ *
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface IdentityRepository
+{
+ Set<IdentityStore> getConfiguredIdentityStores();
+}
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java 2008-06-04 18:41:14 UTC (rev 10922)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -35,11 +35,11 @@
public interface IdentityStore
{
- public String getIdentityStoreId();
+ String getIdentityStoreId();
- public Set<GroupType> getSupportedGroupTypes();
+ Set<GroupType> getSupportedGroupTypes();
- public boolean isUserStore();
+ boolean isUserStore();
// TODO: Set of needed methods
Deleted: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relation.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relation.java 2008-06-04 18:41:14 UTC (rev 10922)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relation.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -1,39 +0,0 @@
-/*
-* JBoss, a division of Red Hat
-* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
-* by the @authors tag. See the copyright.txt in the distribution for a
-* full listing of individual contributors.
-*
-* This is free software; you can redistribute it and/or modify it
-* under the terms of the GNU Lesser General Public License as
-* published by the Free Software Foundation; either version 2.1 of
-* the License, or (at your option) any later version.
-*
-* This software is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this software; if not, write to the Free
-* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-*/
-
-package org.jboss.portal.identity2.spi;
-
-import org.jboss.portal.identity2.api.RelationType;
-
-/**
- * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
- * @version : 0.1 $
- */
-public interface Relation
-{
- public GroupEntity getFrom();
-
- public GroupEntity getTo();
-
- public RelationType getType();
-
-}
Copied: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relationship.java (from rev 10922, modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relation.java)
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relationship.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relationship.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -0,0 +1,39 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.spi;
+
+import org.jboss.portal.identity2.api.RelationshipType;
+
+/**
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface Relationship
+{
+ GroupEntity getFrom();
+
+ GroupEntity getTo();
+
+ RelationshipType getType();
+
+}
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java 2008-06-04 18:41:14 UTC (rev 10922)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -24,6 +24,7 @@
import java.util.List;
import java.util.Map;
+import java.util.Collection;
/**
* @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
@@ -32,12 +33,12 @@
public interface UserEntity
{
- public Object getId();
+ Object getId();
- public String getUserName();
+ String getUserName();
- public Map<String, String[]> getAttributes();
+ Map<String, String[]> getAttributes();
- public List<GroupEntity> getGroupEntities();
+ Collection<GroupEntity> getGroupEntities();
}
17 years, 11 months
JBoss Portal SVN: r10922 - in modules/identity/trunk/identity/src/main/java/org/jboss/portal: identity2 and 2 other directories.
by portal-commits@lists.jboss.org
Author: bdaw
Date: 2008-06-04 14:41:14 -0400 (Wed, 04 Jun 2008)
New Revision: 10922
Added:
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/GroupType.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationType.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityService.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relation.java
modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java
Log:
Playing a bit with the interfaces...
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,111 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.api;
+
+
+import java.util.Map;
+import java.util.Set;
+
+/**
+ *
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface Group
+{
+
+ /**
+ * @return group id
+ */
+ public Object getId();
+
+ /**
+ * @return group name
+ */
+ public String getName();
+
+ /**
+ * @return group type
+ */
+ public GroupType getType();
+
+ /**
+ * @return map containing group attributes
+ */
+ public Map<String, String[]> getAttributes();
+
+ /**
+ * Update user attribute values
+ * @param group
+ * @param attrName
+ * @param values
+ * @return
+ */
+ public boolean updateAttribute(Group group, String attrName, String[] values);
+
+ /**
+ * @return id of parent group for the relations of RelationType.HIERARCHICAL. If the parent id is null, this object
+ * is a child of a root group in the store
+ */
+ public Object getParentId();
+
+ /**
+ * @return set of users assigned to this group
+ */
+ public Set<User> getUsers();
+
+ /**
+ * @return set of groups that are either children of this group or implied for this group
+ */
+ public Set<Group> getGroups();
+
+ /**
+ * @param type of the relation
+ * @return set of groups that have given relation type with this group and the direction of the relation is towords
+ * this group
+ */
+ public Set<Group> getGroups(RelationType type);
+
+ /**
+ * @param group
+ * @return returns a relation type between this and given group.
+ */
+ public RelationType getRelation(Group group);
+
+ /**
+ * Assign a set of groups to this group. All other group associations (with this relation type) for this group
+ * will be overrwitten
+ * @param toGroups
+ * @param type
+ * @return
+ */
+ public boolean assignGroups(Set<Group> toGroups, RelationType type);
+
+ /**
+ * Assign a set of users to this group. All other user associations will be overwritten for this group
+ * @param users
+ * @return
+ */
+ public boolean assignUsers(Set<User> users);
+
+}
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/GroupType.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/GroupType.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/GroupType.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,44 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+package org.jboss.portal.identity2.api;
+
+/**
+ * Type of a group
+ */
+public enum GroupType
+{
+
+ // Administration group - just to group users for common admin tasks
+ ADMINISTRATION,
+
+ // Organization (location, division, department, team...)
+ ORGANIZATION,
+
+ // Business role (manager, director, leader...)
+ BUSINESS,
+
+ // JEE security role
+ JEE,
+
+ // Community of users
+ COMMUNITY
+}
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,123 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.api;
+
+
+import java.util.Map;
+import java.util.Set;
+
+/**
+ * IdentityModule exposes operations to creat/destroy/find users and roles. Methods to manipulate those objects and
+ * their relationships are exposed directly in Group and User classes.
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface IdentityModule
+{
+ // Users
+
+ /**
+ * Create new user in the data store
+ * @param userName
+ * @return
+ */
+ public User createUser(String userName);
+
+ /**
+ * Remove user from the the data store
+ * @param user
+ * @return
+ */
+ public boolean removeUser(User user);
+
+ /**
+ * Find user with a given user name
+ * @param userName
+ * @return
+ */
+ public User findUser(String userName);
+
+ /**
+ * Find user with a given id
+ * @param id
+ * @return
+ */
+ public User findUser(Object id);
+
+ /**
+ * Find users with a given properties values
+ * @param properties
+ * @return
+ */
+ public Set<Group> findUsers(Map<String, String[]> properties);
+
+
+ // Groups
+
+ /**
+ * Create new group in the data store
+ * @param groupName
+ * @return
+ */
+ public Group createGroup(String groupName, GroupType type);
+
+ /**
+ * Remove group from the data store
+ * @param group
+ * @return
+ */
+ public boolean removeGroup(Group group);
+
+ /**
+ * Find group with a given name
+ * @param name
+ * @return
+ */
+ public Group findGroup(String name);
+
+ /**
+ * Find Group with a given object id
+ * @param id
+ * @return
+ */
+ public Group findGroup(Object id);
+
+ /**
+ * Find Group with a given group type
+ * @param groupType
+ * @return
+ */
+ public Group findGroup(GroupType groupType);
+
+ /**
+ * Find groups with a given attributes values
+ * @param properties
+ * @return
+ */
+ public Set<Group> findGroups(Map<String, String[]> properties);
+
+
+
+
+
+}
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationType.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationType.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/RelationType.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,35 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.api;
+
+/**
+ * Relation between two groups
+ */
+public enum RelationType
+{
+ // Tree like hierarchy (parent -> children)
+ HIERARCHICAL,
+
+ // Implied
+ IMPLIED
+}
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/User.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,77 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.api;
+
+import java.util.Map;
+import java.util.Set;
+
+/**
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface User
+{
+
+ /**
+ * @return user id
+ */
+ public Object getId();
+
+ /**
+ * @return user name
+ */
+ public String getUserName();
+
+ /**
+ * @return map containing user attributes
+ */
+ public Map<String, String[]> getAttributes();
+
+ /**
+ * Update user attribute values
+ * @param user
+ * @param attrName
+ * @param values
+ * @return
+ */
+ public boolean updateAttribute(User user, String attrName, String[] values);
+
+ /**
+ * @return a set of groups that this user belongs to
+ */
+ public Set<Group> getGroups();
+
+ /**
+ * @param groupType
+ * @return a set of groups with a given groupType that this user belongs to
+ */
+ public Set<Group> getGroups(GroupType groupType);
+
+ /**
+ * Assign a set of groups to this user. All other group associations will be overwritten
+ * @param groups
+ * @return
+ */
+ public boolean assignGroups(Set<Group> groups);
+
+}
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/GroupEntity.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,52 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.spi;
+
+import org.jboss.portal.identity2.api.GroupType;
+
+import java.util.List;
+import java.util.Map;
+
+/**
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface GroupEntity
+{
+ public Object getId();
+
+ public String getName();
+
+ public GroupType getType();
+
+ public Map<String, String[]> getAttributes();
+
+ public Object getParentId();
+
+ public List<Relation> getFromRelations();
+
+ public List<Relation> getToRelations();
+
+ public List<UserEntity> getUserEntities();
+
+}
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityService.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityService.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityService.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,37 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.spi;
+
+import java.util.Set;
+
+/**
+ * IdentityService exposes identity object management operations and act as an entry point to the underlaying data stores.
+ * Its responsibility is to map identity objects, their state and relations between them across different identity stores.
+ *
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface IdentityService
+{
+ public Set<IdentityStore> getConfiguredIdentityStores();
+}
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/IdentityStore.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,48 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.spi;
+
+import org.jboss.portal.identity2.api.GroupType;
+
+import java.util.Map;
+import java.util.List;
+import java.util.Set;
+
+/**
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface IdentityStore
+{
+
+ public String getIdentityStoreId();
+
+ public Set<GroupType> getSupportedGroupTypes();
+
+ public boolean isUserStore();
+
+
+ // TODO: Set of needed methods
+
+
+}
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relation.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relation.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/Relation.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,39 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.spi;
+
+import org.jboss.portal.identity2.api.RelationType;
+
+/**
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface Relation
+{
+ public GroupEntity getFrom();
+
+ public GroupEntity getTo();
+
+ public RelationType getType();
+
+}
Added: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java
===================================================================
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java (rev 0)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/spi/UserEntity.java 2008-06-04 18:41:14 UTC (rev 10922)
@@ -0,0 +1,43 @@
+/*
+* JBoss, a division of Red Hat
+* Copyright 2006, Red Hat Middleware, LLC, and individual contributors as indicated
+* by the @authors tag. See the copyright.txt in the distribution for a
+* full listing of individual contributors.
+*
+* This is free software; you can redistribute it and/or modify it
+* under the terms of the GNU Lesser General Public License as
+* published by the Free Software Foundation; either version 2.1 of
+* the License, or (at your option) any later version.
+*
+* This software is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+* Lesser General Public License for more details.
+*
+* You should have received a copy of the GNU Lesser General Public
+* License along with this software; if not, write to the Free
+* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+*/
+
+package org.jboss.portal.identity2.spi;
+
+import java.util.List;
+import java.util.Map;
+
+/**
+ * @author <a href="mailto:boleslaw dot dawidowicz at redhat anotherdot com">Boleslaw Dawidowicz</a>
+ * @version : 0.1 $
+ */
+public interface UserEntity
+{
+
+ public Object getId();
+
+ public String getUserName();
+
+ public Map<String, String[]> getAttributes();
+
+ public List<GroupEntity> getGroupEntities();
+
+}
17 years, 11 months
JBoss Portal SVN: r10921 - in branches/JBoss_Portal_Branch_2_7: faces/src/main/org/jboss/portal/faces/component/portlet and 1 other directory.
by portal-commits@lists.jboss.org
Author: chris.laprun(a)jboss.com
Date: 2008-06-04 13:13:15 -0400 (Wed, 04 Jun 2008)
New Revision: 10921
Modified:
branches/JBoss_Portal_Branch_2_7/core-admin/src/main/org/jboss/portal/core/admin/ui/common/PageManagerBean.java
branches/JBoss_Portal_Branch_2_7/faces/src/main/org/jboss/portal/faces/component/portlet/JSFInvocation.java
branches/JBoss_Portal_Branch_2_7/faces/src/main/org/jboss/portal/faces/component/portlet/UIPortlet.java
Log:
- More generics.
- Minor improvements.
Modified: branches/JBoss_Portal_Branch_2_7/core-admin/src/main/org/jboss/portal/core/admin/ui/common/PageManagerBean.java
===================================================================
--- branches/JBoss_Portal_Branch_2_7/core-admin/src/main/org/jboss/portal/core/admin/ui/common/PageManagerBean.java 2008-06-04 13:42:23 UTC (rev 10920)
+++ branches/JBoss_Portal_Branch_2_7/core-admin/src/main/org/jboss/portal/core/admin/ui/common/PageManagerBean.java 2008-06-04 17:13:15 UTC (rev 10921)
@@ -413,7 +413,7 @@
this.selectedContentURI = uri;
// TODO: Get params from the payload (for widgets)
- this.selectedContentParameters = new HashMap();
+ this.selectedContentParameters = eventEvent.getParameterMap();
}
}
else if (event instanceof PortletActionEvent)
Modified: branches/JBoss_Portal_Branch_2_7/faces/src/main/org/jboss/portal/faces/component/portlet/JSFInvocation.java
===================================================================
--- branches/JBoss_Portal_Branch_2_7/faces/src/main/org/jboss/portal/faces/component/portlet/JSFInvocation.java 2008-06-04 13:42:23 UTC (rev 10920)
+++ branches/JBoss_Portal_Branch_2_7/faces/src/main/org/jboss/portal/faces/component/portlet/JSFInvocation.java 2008-06-04 17:13:15 UTC (rev 10921)
@@ -59,7 +59,6 @@
import javax.faces.context.FacesContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
-import java.util.Iterator;
import java.util.Map;
/**
@@ -139,14 +138,12 @@
//
PortletRequestEncoder encoder = new PortletRequestEncoder();
encoder.encodeRender(actionPortletURL.getInteractionState(), portletURL.getMode(), portletURL.getWindowState());
- for (Iterator i = encoder.getQueryParameters().entrySet().iterator(); i.hasNext();)
+ for (Map.Entry entry : encoder.getQueryParameters().entrySet())
{
- Map.Entry entry = (Map.Entry)i.next();
String name = FastURLEncoder.getUTF8Instance().encode((String)entry.getKey());
String[] values = (String[])entry.getValue();
- for (int j = 0; j < values.length; j++)
+ for (String value : values)
{
- String value = values[j];
url.append("&").append(name).append('=');
FastURLEncoder.getUTF8Instance().encode(value, url);
}
Modified: branches/JBoss_Portal_Branch_2_7/faces/src/main/org/jboss/portal/faces/component/portlet/UIPortlet.java
===================================================================
--- branches/JBoss_Portal_Branch_2_7/faces/src/main/org/jboss/portal/faces/component/portlet/UIPortlet.java 2008-06-04 13:42:23 UTC (rev 10920)
+++ branches/JBoss_Portal_Branch_2_7/faces/src/main/org/jboss/portal/faces/component/portlet/UIPortlet.java 2008-06-04 17:13:15 UTC (rev 10921)
@@ -27,11 +27,11 @@
import org.jboss.portal.common.NotYetImplemented;
import org.jboss.portal.common.util.ParameterMap;
import org.jboss.portal.faces.util.ActionEventDispatcher;
+import org.jboss.portal.portlet.ParametersStateString;
import org.jboss.portal.portlet.Portlet;
import org.jboss.portal.portlet.PortletContext;
import org.jboss.portal.portlet.PortletInvoker;
import org.jboss.portal.portlet.PortletInvokerException;
-import org.jboss.portal.portlet.ParametersStateString;
import org.jboss.portal.portlet.impl.PortletRequestDecoder;
import org.jboss.portal.portlet.invocation.response.FragmentResponse;
import org.jboss.portal.portlet.invocation.response.InsufficientPrivilegesResponse;
@@ -39,6 +39,7 @@
import org.jboss.portal.portlet.invocation.response.UpdateNavigationalStateResponse;
import javax.faces.component.UICommand;
+import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;
import javax.faces.el.MethodBinding;
@@ -49,10 +50,8 @@
import javax.portlet.ActionRequest;
import javax.portlet.EventRequest;
import javax.portlet.RenderRequest;
-
import java.io.IOException;
import java.util.HashMap;
-import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
@@ -449,18 +448,17 @@
public void decode(FacesContext faces)
{
String clientId = getClientId(faces);
- String clientIdValue = (String)faces.getExternalContext().getRequestParameterMap().get(clientId);
-
- Object obj = faces.getExternalContext().getRequest();
+ ExternalContext externalContext = faces.getExternalContext();
+ String clientIdValue = (String)externalContext.getRequestParameterMap().get(clientId);
- // We have been targetted
+ // We have been targeted
if ("jbp".equals(clientIdValue))
{
- Map jsfParams = faces.getExternalContext().getRequestParameterValuesMap();
+ Map jsfParams = externalContext.getRequestParameterValuesMap();
Map portletParams = new HashMap();
- for (Iterator i = jsfParams.entrySet().iterator(); i.hasNext();)
+ for (Object o : jsfParams.entrySet())
{
- Map.Entry entry = (Map.Entry)i.next();
+ Map.Entry entry = (Map.Entry)o;
String name = (String)entry.getKey();
if (clientId.equals(name))
{
@@ -468,7 +466,7 @@
}
else
{
- String[] values = (String[])((String[])entry.getValue()).clone();
+ String[] values = ((String[])entry.getValue()).clone();
portletParams.put(name, values);
}
}
@@ -479,7 +477,8 @@
Mode mode = decoder.getMode();
WindowState windowState = decoder.getWindowState();
- if (obj instanceof RenderRequest)
+ Object request = externalContext.getRequest();
+ if (request instanceof RenderRequest)
{
PortletRenderEvent prevent = new PortletRenderEvent(
this,
@@ -489,7 +488,7 @@
prevent.setPhaseId(PhaseId.INVOKE_APPLICATION);
queueEvent(prevent);
}
- else if (obj instanceof ActionRequest)
+ else if (request instanceof ActionRequest)
{
if (mode == null)
{
@@ -501,13 +500,13 @@
}
PortletActionEvent paevent = new PortletActionEvent(
this,
- ParameterMap.clone(((ActionRequest)obj).getParameterMap()),
+ ParameterMap.clone(((ActionRequest)request).getParameterMap()),
mode,
windowState);
paevent.setPhaseId(PhaseId.INVOKE_APPLICATION);
queueEvent(paevent);
}
- else if (obj instanceof EventRequest)
+ else if (request instanceof EventRequest)
{
throw new NotYetImplemented();
}
17 years, 11 months
JBoss Portal SVN: r10920 - modules/common/trunk/common/src/main/java/org/jboss/portal/common/net.
by portal-commits@lists.jboss.org
Author: thomas.heute(a)jboss.com
Date: 2008-06-04 09:42:23 -0400 (Wed, 04 Jun 2008)
New Revision: 10920
Modified:
modules/common/trunk/common/src/main/java/org/jboss/portal/common/net/URLTools.java
Log:
JBPORTAL-2034: use http.proxyUser and http.proxyPassword for proxy authentication
Modified: modules/common/trunk/common/src/main/java/org/jboss/portal/common/net/URLTools.java
===================================================================
--- modules/common/trunk/common/src/main/java/org/jboss/portal/common/net/URLTools.java 2008-06-04 13:35:16 UTC (rev 10919)
+++ modules/common/trunk/common/src/main/java/org/jboss/portal/common/net/URLTools.java 2008-06-04 13:42:23 UTC (rev 10920)
@@ -31,7 +31,9 @@
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
+import java.net.Authenticator;
import java.net.MalformedURLException;
+import java.net.PasswordAuthentication;
import java.net.SocketTimeoutException;
import java.net.URL;
import java.net.URLConnection;
@@ -118,6 +120,17 @@
throw new IllegalArgumentException("No negative connection timeout" + connTimeoutMillis);
}
+ if (System.getProperty("http.proxyUser") != null)
+ {
+ Authenticator.setDefault(new Authenticator(){
+
+ protected PasswordAuthentication getPasswordAuthentication()
+ {
+ return (new PasswordAuthentication(System.getProperty("http.proxyUser"), System.getProperty("http.proxyPassword").toCharArray()));
+ }
+ });
+ }
+
//
URLConnection conn;
try
17 years, 11 months
JBoss Portal SVN: r10919 - modules/common/branches/JBP_COMMON_BRANCH_1_1/common/src/main/java/org/jboss/portal/common/net.
by portal-commits@lists.jboss.org
Author: thomas.heute(a)jboss.com
Date: 2008-06-04 09:35:16 -0400 (Wed, 04 Jun 2008)
New Revision: 10919
Modified:
modules/common/branches/JBP_COMMON_BRANCH_1_1/common/src/main/java/org/jboss/portal/common/net/URLTools.java
Log:
use http.proxyUser and http.proxyPassword for authentication
Modified: modules/common/branches/JBP_COMMON_BRANCH_1_1/common/src/main/java/org/jboss/portal/common/net/URLTools.java
===================================================================
--- modules/common/branches/JBP_COMMON_BRANCH_1_1/common/src/main/java/org/jboss/portal/common/net/URLTools.java 2008-06-04 13:17:50 UTC (rev 10918)
+++ modules/common/branches/JBP_COMMON_BRANCH_1_1/common/src/main/java/org/jboss/portal/common/net/URLTools.java 2008-06-04 13:35:16 UTC (rev 10919)
@@ -31,7 +31,9 @@
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
+import java.net.Authenticator;
import java.net.MalformedURLException;
+import java.net.PasswordAuthentication;
import java.net.SocketTimeoutException;
import java.net.URL;
import java.net.URLConnection;
@@ -118,6 +120,17 @@
throw new IllegalArgumentException("No negative connection timeout" + connTimeoutMillis);
}
+ if (System.getProperty("http.proxyUser") != null)
+ {
+ Authenticator.setDefault(new Authenticator(){
+
+ protected PasswordAuthentication getPasswordAuthentication()
+ {
+ return (new PasswordAuthentication(System.getProperty("http.proxyUser"), System.getProperty("http.proxyPassword").toCharArray()));
+ }
+ });
+ }
+
//
URLConnection conn;
try
17 years, 11 months
JBoss Portal SVN: r10918 - branches/JBoss_Portal_Branch_2_7/core/src/main/org/jboss/portal/core/impl/model/content/generic.
by portal-commits@lists.jboss.org
Author: chris.laprun(a)jboss.com
Date: 2008-06-04 09:17:50 -0400 (Wed, 04 Jun 2008)
New Revision: 10918
Modified:
branches/JBoss_Portal_Branch_2_7/core/src/main/org/jboss/portal/core/impl/model/content/generic/InternalGenericContentProvider.java
Log:
- Minor optimization possible with PC post CR2 (todo).
Modified: branches/JBoss_Portal_Branch_2_7/core/src/main/org/jboss/portal/core/impl/model/content/generic/InternalGenericContentProvider.java
===================================================================
--- branches/JBoss_Portal_Branch_2_7/core/src/main/org/jboss/portal/core/impl/model/content/generic/InternalGenericContentProvider.java 2008-06-04 01:24:04 UTC (rev 10917)
+++ branches/JBoss_Portal_Branch_2_7/core/src/main/org/jboss/portal/core/impl/model/content/generic/InternalGenericContentProvider.java 2008-06-04 13:17:50 UTC (rev 10918)
@@ -22,10 +22,11 @@
******************************************************************************/
package org.jboss.portal.core.impl.model.content.generic;
+import org.apache.log4j.Logger;
import org.jboss.portal.Mode;
-import org.jboss.portal.identity.User;
import org.jboss.portal.common.i18n.LocalizedString;
import org.jboss.portal.common.util.ParameterMap;
+import org.jboss.portal.core.CoreConstants;
import org.jboss.portal.core.impl.model.content.InternalContentProvider;
import org.jboss.portal.core.model.content.Content;
import org.jboss.portal.core.model.content.ContentType;
@@ -37,20 +38,19 @@
import org.jboss.portal.core.model.instance.InstanceContainer;
import org.jboss.portal.core.model.portal.Window;
import org.jboss.portal.core.model.portal.command.response.MarkupResponse;
+import org.jboss.portal.core.model.portal.content.ContentRendererContext;
import org.jboss.portal.core.model.portal.content.WindowRendition;
-import org.jboss.portal.core.model.portal.content.ContentRendererContext;
-import org.jboss.portal.core.CoreConstants;
-import org.jboss.portal.portlet.invocation.RenderInvocation;
-import org.jboss.portal.portlet.controller.state.WindowNavigationalState;
+import org.jboss.portal.identity.User;
import org.jboss.portal.portlet.Portlet;
import org.jboss.portal.portlet.PortletInvokerException;
-import org.jboss.portal.portlet.info.PortletInfo;
+import org.jboss.portal.portlet.controller.state.WindowNavigationalState;
import org.jboss.portal.portlet.info.NavigationInfo;
import org.jboss.portal.portlet.info.ParameterInfo;
-import org.apache.log4j.Logger;
+import org.jboss.portal.portlet.info.PortletInfo;
+import org.jboss.portal.portlet.invocation.RenderInvocation;
+import java.util.Collections;
import java.util.Map;
-import java.util.Collections;
/**
* @author <a href="mailto:julien@jboss.org">Julien Viet</a>
@@ -206,7 +206,8 @@
PortletInfo portletInfo = portlet.getInfo();
NavigationInfo navigationInfo = portletInfo.getNavigation();
- // todo : remove me when there is a getParameter(String id);
+ // todo : use instead of loop (waiting for new version of PC 2.0 that has the method):
+ //id = navigationInfo.getPublicParameter(CoreConstants.JBOSS_PORTAL_CONTENT_URI);
for (ParameterInfo parameterInfo : navigationInfo.getPublicParameters())
{
if (parameterInfo.getName().equals(CoreConstants.JBOSS_PORTAL_CONTENT_URI))
17 years, 11 months
JBoss Portal SVN: r10917 - docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules.
by portal-commits@lists.jboss.org
Author: mmcallis
Date: 2008-06-03 21:24:04 -0400 (Tue, 03 Jun 2008)
New Revision: 10917
Modified:
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/xmldescriptors.xml
Log:
spelling correction and missed a trademark
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/xmldescriptors.xml
===================================================================
--- docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/xmldescriptors.xml 2008-06-04 01:15:52 UTC (rev 10916)
+++ docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/xmldescriptors.xml 2008-06-04 01:24:04 UTC (rev 10917)
@@ -1556,7 +1556,7 @@
</mediaobject>
</para>
<para>
- The <filename>jboss-portal-<replaceable>version</replaceable>/setup/</filename> directory contains sample Datasource descriptors for the MySQL, <trademark class="registered">Microsoft SQL Server</trademark>, PostgreSQL, and Oracale databases, which can be customized for your own database:
+ The <filename>jboss-portal-<replaceable>version</replaceable>/setup/</filename> directory contains sample Datasource descriptors for the MySQL, <trademark class="registered">Microsoft SQL Server</trademark>, PostgreSQL, and <trademark class="registered">Oracle</trademark> databases, which can be customized for your own database:
</para>
<para>
<mediaobject>
17 years, 11 months
JBoss Portal SVN: r10916 - docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules.
by portal-commits@lists.jboss.org
Author: mmcallis
Date: 2008-06-03 21:15:52 -0400 (Tue, 03 Jun 2008)
New Revision: 10916
Modified:
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/security.xml
docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/supported.xml
Log:
I did the UNIX trademarks wrong. This committ
(hopefully) fixes them, as per: http://www.unix.org/tmug2.pdf
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/security.xml
===================================================================
--- docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/security.xml 2008-06-03 18:30:45 UTC (rev 10915)
+++ docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/security.xml 2008-06-04 01:15:52 UTC (rev 10916)
@@ -206,7 +206,7 @@
<xmbean/>
<!--
NOTE: cmsRootUserName denotes a single Portal user that has access to everything in the CMS. Denote this user
- carefully and should be synonymous to the 'root' user in a UNIX system. By default: this value is the built-in
+ carefully and should be synonymous to the 'root' user in UNIX® operating systems. By default: this value is the built-in
'admin' user account. This can be changed to any other user account registered in your Portal
-->
<attribute name="CmsRootUserName">admin</attribute>
@@ -268,7 +268,7 @@
<title>CMS Super User</title>
<para>
A CMS Super User is a designated Portal User Account that has access to all resources/functions in the CMS. It is a concept similar to the
- super user concept in a Linux and <trademark class="registered">UNIX</trademark> security system. This account should be carefully used and properly protected. By default, JBoss Portal designates the
+ super user concept in a Linux and <trademark class="registered">UNIX</trademark> security systems. This account should be carefully used and properly protected. By default, JBoss Portal designates the
built-in 'admin' user account as a CMS Super User. This can be changed by modifying the <emphasis>cmsRootUserName</emphasis> value in the
<literal>jboss-portal.sar/portal-cms.sar/META-INF/jboss-service.xml</literal> configuration.
<programlisting>
@@ -281,7 +281,7 @@
<xmbean/>
<!--
NOTE: cmsRootUserName denotes a single Portal user that has access to everything in the CMS. Denote this user
- carefully and should be synonymous to the 'root' user in a UNIX system. By default: this value is the built-in
+ carefully and should be synonymous to the 'root' user in UNIX® operating systems. By default: this value is the built-in
'admin' user account. This can be changed to any other user account registered in your Portal
-->
<attribute name="CmsRootUserName">admin</attribute>
Modified: docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/supported.xml
===================================================================
--- docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/supported.xml 2008-06-03 18:30:45 UTC (rev 10915)
+++ docs/branches/JBoss_Portal_Branch_2_6/referenceGuide/en/modules/supported.xml 2008-06-04 01:15:52 UTC (rev 10916)
@@ -32,7 +32,7 @@
<sect1>
<title>Supported Operating Systems</title>
<para>JBoss Portal is 100% pure Java, and therefore it is interoperable with most Operating Systems
- capable of running a Java Virtual Machine (JVM). These Operating Systems include but are not limited to: Linux, <trademark class="registered">Windows</trademark>, <trademark class="registered">UNIX</trademark>, and Mac OS X.
+ capable of running a Java Virtual Machine (JVM), including Linux, <trademark class="registered">Windows</trademark>, <trademark class="registered">UNIX</trademark> operating systems, and Mac OS X.
</para>
</sect1>
<sect1>
@@ -63,6 +63,6 @@
</sect1>
<sect1>
<title>Source building</title>
- <para>The source building mechanism works on Linux, <trademark class="registered">Windows</trademark>, Mac OS X, and any UNIX-like operating system.</para>
+ <para>The source building mechanism works on Linux, <trademark class="registered">Windows</trademark>, Mac OS X, and <trademark class="registered">UNIX</trademark> operating systems.</para>
</sect1>
</chapter>
17 years, 11 months
--- modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java 2008-06-04 18:41:14 UTC (rev 10922)
+++ modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/Group.java 2008-06-04 18:59:16 UTC (rev 10923)
@@ -25,6 +25,7 @@
import java.util.Map;
import java.util.Set;
+import java.util.Collection;
/**
*
@@ -56,12 +57,11 @@
/**
* Update user attribute values
- * @param group
* @param attrName
* @param values
* @return
*/
- public boolean updateAttribute(Group group, String attrName, String[] values);
+ public boolean updateAttribute(String attrName, String[] values);
/**
* @return id of parent group for the relations of RelationType.HIERARCHICAL. If the parent id is null, this object
@@ -84,13 +84,13 @@
* @return set of groups that have given relation type with this group and the direction of the relation is towords
* this group
*/
- public Set<Group> getGroups(RelationType type);
+ public Set<Group> getGroups(RelationshipType type);
/**
* @param group
* @return returns a relation type between this and given group.
*/
- public RelationType getRelation(Group group);
+ public RelationshipType getRelationship(Group group);
/**
* Assign a set of groups to this group. All other group associations (with this relation type) for this group
@@ -99,7 +99,7 @@
* @param type
* @return
*/
- public boolean assignGroups(Set<Group> toGroups, RelationType type);
+ public boolean assignGroups(Set<Group> toGroups, RelationshipType type);
/**
* Assign a set of users to this group. All other user associations will be overwritten for this group
Modified: modules/identity/trunk/identity/src/main/java/org/jboss/portal/identity2/api/IdentityModule.java
@@ -84,13 +84,13 @@
/**
* @param group
- * @return returns a relation type between this and given group.
+ * @return returns a relationship type between this and given group.
*/
===================================================================